@@ -153,15 +153,6 @@ fn array_coverage() {
     check_percentage("arrays", 1.0f64, true);
 }
 
-#[test]
-#[ignore]
-fn dependency_build_script() {
-    // From issue #1297
-    // TODO metatensor isn't really maintained that frequently and has broken on nightly. Find an
-    // alternative project to test this (or make one)
-    check_percentage("metatensor", 1.0f64, true);
-}
-
 #[test]
 fn lets_coverage() {
     check_percentage("lets", 1.0f64, true);
@@ -254,7 +245,6 @@ fn method_calls_expr_coverage() {
 }
 
 #[test]
-//#[cfg(not(windows))] // TODO fix
 fn config_file_coverage() {
     let test_dir = get_test_path("configs");
     let mut args = vec![
@@ -298,18 +288,6 @@ fn match_expr_coverage() {
     check_percentage("matches", 1.0f64, true);
 }
 
-#[test]
-#[ignore]
-fn benchmark_coverage() {
-    let test = "benchmark_coverage";
-    check_percentage(test, 0.0f64, true);
-
-    let mut config = Config::default();
-    config.set_clean(false);
-    config.run_types = vec![RunType::Benchmarks];
-    check_percentage_with_config(test, 1.0f64, true, config);
-}
-
 #[test]
 fn cargo_run_coverage() {
     let mut config = Config::default();
@@ -430,6 +408,23 @@ fn handle_module_level_exclude_attrs() {
     check_percentage("crate_level_ignores", 1.0f64, true);
 }
 
+#[test]
+fn module_name_clashes() {
+    // Make sure the exclusions are correct
+    let mut config = Config::default();
+    config.set_include_tests(false);
+    config.set_clean(false);
+    let map = check_percentage_with_config("module_name_clashes", 1.0f64, true, config);
+
+    println!("{:?}", map.files());
+
+    let root = get_test_path("module_name_clashes");
+
+    assert!(map.contains_file(&root.join("src/foo/overhere.rs")));
+    assert!(map.contains_file(&root.join("src/foo/boo.rs")));
+    assert!(!map.contains_file(&root.join("src/foo/bar/overhere/boo.rs")));
+}
+
 #[test]
 #[cfg(unix)]
 fn handle_forks() {
